/**************************************************************************************************
	            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
   DIRECCIN GENERAL PARA LA INTEGRACIN Y ANLISIS DE LA INFORMACIN
*****************************************************************************************************/


/******************************************************************************* 
NOMBRE DEL PROGRAMA: RE02ab_PEM2015.SAS
--------------------------------------------------------------------------------
DESCRIPCIN DEL PROGRAMA: 
Programa que calcula los valores, tablas finales e insumos para graficar el indicador
"Tasa de ocupacin segn nivel de escolaridad (2015)"
"Porcentaje de trabajadores con contratacin estable segn nivel de escolaridad (2015)"
indicador del Panorama Educativo de Mxico 2015.
--------------------------------------------------------------------------------
NOMBRE Y DESCRIPCIN DE ARCHIVOS DE ENTRADA:  
1.		SDEMT2
        COE1T2;
        COE2T2;

Fuente(s): 
INEGI (2015). Encuesta Nacional de Ocupacin y Empleo, 2 trimestre  de 2015 (base de microdatos).
--------------------------------------------------------------------------------
NOMBRE Y DESCRIPCIN DE ARCHIVOS DE SALIDA: 
TasaOcupacionENOE2015&b.a&i._&s..xls  Es el archivo en formato de excel con las tablas del indicador 
CONTRATACIN_ESTABLE_2015&b.b&i._&s..xls  Es el archivo en formato de excel con las tablas del indicador 

"Tasa de ocupacin segn nivel de escolaridad (2015)"
"Porcentaje de trabajadores con contratacin estable segn nivel de escolaridad (2015)"
TasaOcupacionENOE2015&b.a&i._&s..xls
Porcentajes del indicador
limites de confianza del indicador
absolutos del indicador

CONTRATACIN_ESTABLE_2015&b.b&i._&s..xls
Porcentajes del indicador
limites de confianza del indicador
absolutos del indicador
--------------------------------------------------------------------------------
INSTRUCCIONES:

1. Modifique la lnea de comando (LIBNAME) de acuerdo con la ruta.
3. Modifique el nombre de los archivos actualizandolos.

5. Modifique el procedimiento de los archivos de salida redireccionaqnadolos en donde
    se ubicarn los archivos de salida. 
6. Ejecute el programa.
*******************************************************************************/
/*******************************************************************************
ELABORADO POR: OSCAR CHAPITAL COLCHADO
		Adscripcin: Direccin de Indicadores Educativos. Subdireccin de Anlisis de Estadsticas Educativas. 
FECHA DE ELABORACIN: 2016/01/28 
LTIMA MODIFICACIN: 2016/02/22 por OSCAR CHAPITAL COLCHADO
*******************************************************************************/

/*DEFINICIN DE LIBRERIAS*/
%MACRO create(o=, b=, j=, c=, d=, e=, f=);
OPTIONS OPTIONS DATE LINESIZE=90 REPLACE PAGESIZE=80;
LIBNAME B 'D:\Desktop\RE03_(2015)\RE03_1entrega_Actualizacincon la ENOE 2015\SAS\SAS';
RUN;
/* IMPORTANTE: LAS BASES TIENEN PONDERADORES PREELIMINARES SOBRE LA ESTIMACIN DE POBLACIN, SE ESPERA LAS NUEVAS PROYECCIONES DE CONAPO*/
/*Secuencia de pegado de bases: SDEMT, COE2T (2013)*/

DATA SDEMT2&b; 
SET &o..SDEMT2&b;
	a=cd_a; x=ent; y=con; z=v_sel; e=n_hog; v=h_mud; g=n_ren;
	key=cat(a, x, y, z, e, v, g); 
RUN;

DATA COE1T2&b;
SET &o..COE1T2&b;
	a=cd_a; x=ent; y=con; z=v_sel; e=n_hog; v=h_mud; g=n_ren;
	key=cat(a, x, y, z, e, v, g); 
RUN;

DATA COE2T2&b;
SET &o..COE2T2&b;
	a=cd_a; x=ent; y=con; z=v_sel; e=n_hog; v=h_mud; g=n_ren;
	key=cat(a, x, y, z, e, v, g); 
RUN;

PROC SORT DATA=SDEMT2&b;
	BY key;
RUN;

PROC SORT DATA=COE1T2&b;
	BY key;
RUN;

PROC SORT DATA=COE2T2&b;
	BY key;
RUN;

DATA ENOE2&b;
MERGE SDEMT2&b (IN=i) COE1T2&b COE2T2&b;
BY key;
IF i;
RUN;

DATA ENOE2&b.a;
SET ENOE2&b;
edad=eda+0;
sexo=sex+0;
estado=ent+0;
IF r_def='00' and c_res in ('1','3');
/*******************Poblacin Ocupada po=1 ****************************************
En 1 instancia: Trabaj por lo menos una hora la s. pasada.
En 2 instancia: Actividad con ingreso o ayud a otra persona.
En 3-a instancia: NO trabaj por huelga, paro, suspensin o cursos de capacitacin.
En 3-b instancia: NO trabaj por alguna otra razn de ausencia, con goce de sueldo.
En 4 instancia: NO trabaj por alguna otra razn de ausencia, sin goce de sueldo,
pero ya se reincorpor en la semana de la entrevista*/

po=0;
p1_n=p1+0;
p1a1_n=p1a1+0;
p1a2_n=p1a2+0;
p1c_n=p1c+0;
p1d_n=p1d+0;
p1e_n=p1e+0;

IF p1_n=1 THEN po=1;
IF p1a1_n=1 OR (p1a2_n=2 and p1a1_n=.) THEN po=1;           
IF p1c_n in (1,2,3,4) or p1d_n=1 THEN po=1;
IF p1d_n in (2,9) AND p1e_n=1 THEN po=1;

/****** Posicin en el trabajo: pos******/

p3h_n=p3h+0;
p3d_n=p3d+0;
p3g1_1n=p3g1_1+0;

	IF p3h_n in (2,3) THEN pos=0;/*subordinada no remunerada;*/
	IF po=1 AND p3h_n=1 THEN pos=1;/*subordinada remunerada; */
	IF p3d_n=1 AND p3g1_1n=1 THEN pos=2;*empleador;
	IF p3d_n in (2,9) OR (p3d_n=1 and p3g1_1n=.) THEN pos=3;*cuentapropia;
	IF po=1 AND p3h_n=9 THEN pos=9;*no espec;


/* Poblacin con contratacin estable (base, planta o indefinido)*/

poce=0;
&j.n=&j+0;
IF po=1 AND &j.n=2 THEN poce=1; /* (cuestionario_2005_ampliado=p3K1 y 2011_bsico=p3j1;*/


/**********************urbana-rural**********************************/

t_locn=t_loc+0;

IF t_locn in (1,2)THEN locur=3;*urbana;
IF t_locn=3       THEN locur=2;*semiurbana;
IF t_locn=4       THEN locur=1;*rural;


/******************* Escolaridad alcanzada **********************************
esc=1 Sin bsica.[Sin inst., pre.][Prim. inc. y gdo. no espec.][Prim. comp.]
[Sec. inc., y gdo. no espec.][Nor. o tc/comer. con prim., gdos: 1-2 y no espec.]
esc=2 Con bsica. [Sec. comp.][Bach. inc. y gdo. No espec.]
[Nor. o tc/comer. con sec., gdos: 1-2 y no espec][Tc/comer. con prim., gdos: 3 o ms]
esc=3 Media superior. [Bach. comp.][Lic. inc., y gdo. no espec.][Tc/comer. con bach., gdos: 1-2 y no espec.]
[Nor. con prim., gdos: 3 o ms (slo 3 casos simples)][Nor. con sec., gdos: 3 o ms]
[Nor. con bach, gdos: 1-3][Tc/comer. con sec., gdos: 3 o ms]
esc=4 Superior.[Tc/comer. con bach., gdos: 3 o ms][Lic. comp.][Nor. con bach., gdos:4 o ms]
[Mtria. inc.][Mtria. comp.][Doc. comp. o inc.]
esc=9 No especificados. nivel n.e (99); y normal o tcnica con antecedente n.e. (9)

/**** Algoritmo sobre la escolaridad acorde con el CINE 2011 ACTUALIZADO ****/
if r_def ^='15'; * Idenficacin para eliminar entrevistas incompletas de la base de datos SDEM; 
niv=cs_p13_1+0;*0=ninguno, 1=pre. 2=prim. 3=sec. 4=ms. 5=normal 6=Tcnica
					7=lic. 8=mtria 9=drado 99= no esp;
gdo=cs_p13_2+0;*Aos aprobados;
ant=cs_p15+0;*1=prim. 2=sec. 3=ms, 9=no esp.;
egreso=cs_p16+0;

/** 				Algoritmo sobre la escolaridad acorde con el CINE2011				    **/
/**  	 Modificacin respecto a los valores encontrados en niv gdo ant de ENOE 2013     	**/
esc=.;

/*********************************************************************************************/
/********** 							SIN BSICA   							**********/
/*********************************************************************************************/
/* CINE 2011, NIVEL 0: Educacin de Primera infancia y poblacin sin instruccin */
IF niv in (0,1)					 		 			THEN esc=1; *[Sin instruccin y con preescolar];
IF niv=2 & gdo in(1:5,9)				 			THEN esc=1; *[Prim. incompleta y gdos no espec.];

/* CINE 2011, NIVEL 1: Educacin Primaria */
IF niv=2 & gdo=6		  				 			THEN esc=1; *[Prim. completa];
IF niv=3 & gdo in (1,2,9) 		 		 			THEN esc=1; *[Sec. inc., y gdo. no espec.];
IF niv=5 & ant=1 & gdo in (1:9) & egreso in (2,9)	THEN esc=1; *[Normal con primaria sin egreso y n.e.];  
IF niv=6 & ant=1 & gdo in (1:9) & egreso in (2,9)	THEN esc=1; *[Carrera tcnica con primaria sin egreso y n.e]; 
/*********************************************************************************************/
/********** 							BSICA   							**********/
/*********************************************************************************************/
/* CINE 2011, NIVEL 2: Educacin Secundaria Baja */
IF niv=3 & gdo=3 						 			THEN esc=2; *[Sec. completa];
IF niv=4 & gdo in (1,2,9) 				 			THEN esc=2; *[Bach. incompleto y gdo. no espec.];
IF niv=6 & ant=1 & gdo in (1:9) & egreso=1 			THEN esc=2; *[Carrera tcnica con primaria con egreso];
IF niv=5 & ant=2 & gdo in (1:9) & egreso in (2,9)	THEN esc=2; *[Normal con secundaria sin egreso y n.e];
IF niv=6 & ant=2 & gdo in (1:9) & egreso in (2,9) 	THEN esc=2; *[Carrera tcnica con secundaria sin egreso y n.e.];

/*********************************************************************************************/
/********** 						EDUCACIN MEDIA SUPERIOR  						**********/
/*********************************************************************************************/
/* CINE 2011, NIVEL 3: Educacin Secundaria Alta */
IF niv=4 & gdo=3					     			THEN esc=3; *[Bach. completo];
IF niv=5 & ant=1 & gdo in (1:9) & egreso=1 			THEN esc=3; *[Normal con primaria y egreso];
IF niv=5 & ant=2 & gdo in (1:9) & egreso=1 			THEN esc=3; *[Normal con secundaria y egreso];
IF niv=6 & ant=2 & gdo in (1:9) & egreso=1 			THEN esc=3; *[Carrera tcnica con secundaria y egreso];
IF niv=5 & ant=3 & gdo in (1:9) & egreso in (2,9) 	THEN esc=3; *[Normal con bachillerato, sin egreso y n.e.];
IF niv=6 & ant=3 & gdo in (1:9) & egreso in (2,9)	THEN esc=3; *[Carrera tcnica con bachillerato, sin egreso y n.e.];
IF niv=7 & gdo in (1:3,9) 		     	 			THEN esc=3; *[Lic. incompleta y gdo. no espec.];

/*********************************************************************************************/
/********** 							EDUCACIN SUPERIOR  						**********/
/*********************************************************************************************/
/* CINE 2011, NIVEL 5: Educacin Terciaria de ciclo corto */
IF niv=6 & ant=3 & gdo in (1:9) & egreso=1			THEN esc=4; *[Carrera tc/comer. con bach., gdos: 3 o ms];

/* CINE 2011, NIVEL 6: EDUCACIN Terciaria profesional */
IF niv=7 & gdo in (4:8) 			     			THEN esc=4; *[Licenciatura completa];
IF niv=5 & ant=3 & gdo in (1:9) & egreso=1	     	THEN esc=4; *[Normal con bach., gdos:4 o ms];
IF niv=8 & gdo in (1,9) 			     			THEN esc=4; *[Maestra incompleta];
/* CINE 2011, NIVEL 7: Nivel de maestra, especializacin o equivalente */
IF niv=8 & gdo in (2:8) 			     			THEN esc=4; *[Maestra completa];
IF niv=9 & gdo in (1:2,9)				 			THEN esc=4; *[Doctorado completo o incompleto];
/* CINE 2011, NIVEL 8: Nivel de dcotorado o equivalente */
IF niv=9 & gdo in (3:8)					 			THEN esc=4; *[Doctorado completo o incompleto];
/*********************************************************************************************/
/********** 				TRATAMIENTO DE CASOS NO ESPECFICADOS 					**********/
/*********************************************************************************************/
/* CINE 2011, NIVEL 9: No clasificaco en otra parte */
IF niv in (5,6) & ant=9 			     			THEN esc=9; *[Nor. o tc/comer., ante. no espec.];
IF niv=99 							     			THEN esc=9; *[Niv. no espec.];
/*********************************************************************************************/
/*********************************************************************************************/
/*****************************Recodificacin horas trabajadas mensuales**********************/
* Un mes promedio del ao tiene 4.345238 semanas;
* 1a posibilidad. Las horas trabajadas la semana pasada son las habituales;
* 2a posibilidad. No trabaj la semana psada;
* 3a posibilidad. Las horas que trabaj la semana pasada no son las habituales;


/***Horas trabajadas mensuales 2005 y 2012 (COE_05 ampliado y COE_12 ampliado)***/

hrmes=.;
&c._thrs_n=&c._thrs+0;    /*Qu das y cuntas horas le dedic...a su trabajo la semana pasada? Total de horas*/
	&d._thrs_n=&d._thrs+0;/*Qu das y cuntas horas le dedica habituralmente... a su trabajo? Total de horas*/
	&e._n=&e+0;			  /*La semana pasada, ...tuvo poco trabajo qu hacer? 1=s; 2=no trabaj la semana pasada*/
	&f._n=&f+0;			  /*Ese es el nmero de horas que habitualmente trabaja...? 1=s; 2=No;*/

	IF (0<&c._thrs_n<999) AND &f._n=1  THEN hrmes=&c._thrs_n*4.345238;*1a posibilidad;
	IF (0<&d._thrs_n<999) AND &e._n=2  THEN hrmes=&d._thrs_n*4.345238;*2a posibilidad;
	IF (0<&d._thrs_n<999) AND &f._n=2  THEN hrmes=&d._thrs_n*4.345238;*3a posibilidad;
	IF &c._thrs_n=999 OR &d._thrs_n=999 THEN hrmes=.;* No especificados;
RUN;
%mend;
%create(o=B, b=15, j=p3j1, c=p5b, d=p5d, e=p5,  f=p5c);




/*
Data ENOE211b; Set ENOE211a; If 14<=edad=<98 then Pob1498=1; run;
PROC FREQ DATA=ENOE211a; TABLES r_def /ALL; WHERE r_def='00' and c_res in ('1','3');WEIGHT fac; RUN; 
Proc freq data=ENOE211b; table po/nopercent norow nocol; where pob1498=1; weight fac; run;
Idem Inegi tabulados: 113 558 599  pobladores totales; Hombres: 55006552; Mujeres: 58552047
14 y ms: 83 698 315; Hombres 14yms: 39 878 721; Mujeres14yms:43 819 594;
La poblacin ocupada de 14 y ms de la base coincide con la de los tabulados de Inegi: 46 355 701*/
/*Data B.Enoe211a; set Enoe211a; run;*/
/*proc freq data=Enoe211a; table hrmes; run;*/




/***********************TASA DE OCUPACIN POR ENTIDAD Y CARACTERSTICAS NACIONALES*****************************************/

%MACRO create(b=, i=, s=);
/*************ENTIDAD FEDERATIVA**********************************************/
ODS HTML FILE="D:\Desktop\SOLICITUDES\RE03\TasaOcupacionENOE2015&b.a&i._&s..xls"
STYLE=barrettsblue;
DATA ENOE2&b.a&i._&s;
SET ENOE2&b.a; 
IF r_def='00' and c_res in ('1','3')and(&i<=edad<=&s);
RUN;
PROC SORT data=ENOE2&b.a&i._&s; By estado; run;
TITLE 'escolaridad por entidad federativa';  /*Datos por entidad para la tabla RE02a-1 y 2*/
PROC SURVEYFREQ DATA=ENOE2&b.a&i._&s;         /*Con esta rutina sacamos los mismos datos que con procsourveymeans*/
TABLE esc*po*estado / COL CL CLWT nototal;
STRATA est;
CLUSTER upm;
WEIGHT fac;
RUN;


PROC SORT DATA=ENOE2&b.a&i._&s; BY  sexo esc ; RUN; /*Datos Nacionales para la tabla RE02a-3 */
TITLE 'escolaridad por caractersticas nacionales';
PROC SURVEYFREQ DATA=ENOE2&b.a&i._&s; 
TABLES po sexo*po*esc po*esc po*sexo locur*po*esc po*locur / COL CL CLWT nototal;
STRATA est;
CLUSTER upm;
WEIGHT fac;
RUN;


PROC FREQ DATA=ENOE2&b.a&i._&s;
TABLES estado*esc esc*sexo esc*locur edad /missing nocol norow nopercent; /*Datos para tabulado RE02a-1A2, 2A2 y 3A1*/
WHERE po=1;*poblacin ocupada segn escolaridad por entidad federativa, tabulados anexo;
WEIGHT fac;
RUN;


PROC FREQ DATA=ENOE2&b.a&i._&s;
TABLES estado*esc esc*sexo esc*locur edad /missing nocol norow nopercent; *poblacin total segn caracterstica y grupo de edad;
WEIGHT fac;
RUN;
ODS HTML CLOSE;
%mend;
*jvenes;
%create(b=15, i=20, s=24);
%create(b=15, i=15, s=19);
%create(b=15, i=15, s=29);
%create(b=15, i=25, s=64);	
%create(b=15, i=14, s=25);
%create(b=15, i=25, s=29);
*Adultos;
%create(b=15, i=25, s=64);
%create(b=15, i=25, s=44);
%create(b=15, i=45, s=64);


/********************POBLACIN CON CONTRATACIN ESTABLE POR ENTIDAD Y CARACTERSTICAS NACIONALES**********************************************
Proc freq data=Enoe211a; table poce; where r_def='00' and c_res in ('1','3')and(14<=edad<=98)and po=1 and pos=1; *weight fac; run;
La poblacin de 14 y ms con contratacin estable total(13 253 288) y por sexo es la misma que la del Inegi
Proc freq data=B.Enoe211a; table poce*esc/nocol norow nopercent; where r_def='00' and c_res in ('1','3')and(25<=edad<=64)and po=1 and pos=1; *weight fac; run;
/*Data B.Enoe211a; set Enoe211a; run;*/

%MACRO create(b=, i=, s=);
ODS HTML FILE="D:\Desktop\SOLICITUDES\RE03\CONTRATACIN_ESTABLE_2015&b.b&i._&s..xls"
STYLE=barrettsblue;
DATA ENOE2&b.b&i._&s;
SET  ENOE2&b.a;
IF r_def='00' and c_res in ('1','3')and(&i<=edad<=&s)and po=1 and pos=1;*slo poblacin ocupada subordinados remunerados;
RUN;

title 'contratacin estable por entidad federativa';/*Datos por entidad para la tabla RE02b-1 y 2*/
PROC SURVEYFREQ DATA=ENOE2&b.b&i._&s;
TABLES esc*poce*estado/ COL CL CLWT nototal;
STRATA est;
CLUSTER upm;
WEIGHT fac;
RUN;

PROC SORT DATA=ENOE2&b.b&i._&s; BY  sexo esc locur ; RUN; /*Datos Nacionales para la tabla RE02b-3 */
TITLE 'escolaridad por caractersticas nacionales';
PROC SURVEYFREQ DATA=ENOE2&b.b&i._&s;
TABLES poce sexo*poce*esc poce*esc poce*sexo locur*poce*esc poce*locur / COL CL CLWT nototal;
STRATA est;
CLUSTER upm;
WEIGHT fac;
RUN;

PROC FREQ DATA=ENOE2&b.b&i._&s;
TABLES pos estado*esc esc*sexo  esc*locur edad /missing nocol norow nopercent;  /*Datos para tabulado RE02b-1A2, 2A2 y 3A1*/
WHERE pos=1 and poce=1;/*Poblacin total ocupada remunerada con contratacin estable, los resultados van al anexo;*/
WEIGHT fac;
RUN;

PROC FREQ DATA=ENOE2&b.b&i._&s;
TABLES pos estado*esc esc*sexo  esc*locur edad /missing nocol norow nopercent;
WHERE pos=1;/*poblacin total remunerada por tipo sexo y tamao de localidad, para corroborar los porcentajes;*/
WEIGHT fac;
RUN;

ODS HTML CLOSE;
%mend;
*jvenes;
%create(b=15, i=15, s=19);
%create(b=15, i=15, s=29);
%create(b=15, i=25, s=64);	
%create(b=15, i=20, s=24);
%create(b=15, i=25, s=29);
%create(b=15, i=15, s=29);
%create(b=15, i=15, s=19);	
%create(b=15, i=20, s=24);
%create(b=15, i=25, s=29);
*Adultos;
%create(b=15, i=25, s=44);
%create(b=15, i=45, s=64);
%create(b=15, i=25, s=64);
%create(b=15, i=25, s=44);
%create(b=15, i=45, s=64);

/********FIN**********/


